# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServiceSubscriptionsResult',
    'AwaitableGetServiceSubscriptionsResult',
    'get_service_subscriptions',
    'get_service_subscriptions_output',
]

@pulumi.output_type
class GetServiceSubscriptionsResult:
    """
    A collection of values returned by getServiceSubscriptions.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, page_number=None, page_size=None, subscription_name=None, subscriptions=None, topic_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if subscription_name and not isinstance(subscription_name, str):
            raise TypeError("Expected argument 'subscription_name' to be a str")
        pulumi.set(__self__, "subscription_name", subscription_name)
        if subscriptions and not isinstance(subscriptions, list):
            raise TypeError("Expected argument 'subscriptions' to be a list")
        pulumi.set(__self__, "subscriptions", subscriptions)
        if topic_name and not isinstance(topic_name, str):
            raise TypeError("Expected argument 'topic_name' to be a str")
        pulumi.set(__self__, "topic_name", topic_name)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of Subscription names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[builtins.int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="subscriptionName")
    def subscription_name(self) -> Optional[builtins.str]:
        """
        The name of the subscription.
        """
        return pulumi.get(self, "subscription_name")

    @property
    @pulumi.getter
    def subscriptions(self) -> Sequence['outputs.GetServiceSubscriptionsSubscriptionResult']:
        """
        A list of Subscriptions. Each element contains the following attributes:
        """
        return pulumi.get(self, "subscriptions")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> builtins.str:
        """
        The name of the topic.
        """
        return pulumi.get(self, "topic_name")


class AwaitableGetServiceSubscriptionsResult(GetServiceSubscriptionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServiceSubscriptionsResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            subscription_name=self.subscription_name,
            subscriptions=self.subscriptions,
            topic_name=self.topic_name)


def get_service_subscriptions(ids: Optional[Sequence[builtins.str]] = None,
                              name_regex: Optional[builtins.str] = None,
                              output_file: Optional[builtins.str] = None,
                              page_number: Optional[builtins.int] = None,
                              page_size: Optional[builtins.int] = None,
                              subscription_name: Optional[builtins.str] = None,
                              topic_name: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServiceSubscriptionsResult:
    """
    This data source provides the Message Notification Service Subscriptions of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.188.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.message.get_service_subscriptions(ids=["example_id"],
        topic_name="tf-example")
    pulumi.export("subscriptionId1", ids.subscriptions[0].id)
    name = alicloud.message.get_service_subscriptions(topic_name="tf-example")
    pulumi.export("subscriptionId2", name.subscriptions[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Subscription IDs.
    :param builtins.str name_regex: A regex string to filter results by Subscription name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str subscription_name: The name of the subscription.
    :param builtins.str topic_name: The name of the topic.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['subscriptionName'] = subscription_name
    __args__['topicName'] = topic_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:message/getServiceSubscriptions:getServiceSubscriptions', __args__, opts=opts, typ=GetServiceSubscriptionsResult).value

    return AwaitableGetServiceSubscriptionsResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        subscription_name=pulumi.get(__ret__, 'subscription_name'),
        subscriptions=pulumi.get(__ret__, 'subscriptions'),
        topic_name=pulumi.get(__ret__, 'topic_name'))
def get_service_subscriptions_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                     name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                     output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                     page_number: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                     page_size: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                     subscription_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                     topic_name: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServiceSubscriptionsResult]:
    """
    This data source provides the Message Notification Service Subscriptions of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.188.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.message.get_service_subscriptions(ids=["example_id"],
        topic_name="tf-example")
    pulumi.export("subscriptionId1", ids.subscriptions[0].id)
    name = alicloud.message.get_service_subscriptions(topic_name="tf-example")
    pulumi.export("subscriptionId2", name.subscriptions[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of Subscription IDs.
    :param builtins.str name_regex: A regex string to filter results by Subscription name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str subscription_name: The name of the subscription.
    :param builtins.str topic_name: The name of the topic.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['subscriptionName'] = subscription_name
    __args__['topicName'] = topic_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:message/getServiceSubscriptions:getServiceSubscriptions', __args__, opts=opts, typ=GetServiceSubscriptionsResult)
    return __ret__.apply(lambda __response__: GetServiceSubscriptionsResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        subscription_name=pulumi.get(__response__, 'subscription_name'),
        subscriptions=pulumi.get(__response__, 'subscriptions'),
        topic_name=pulumi.get(__response__, 'topic_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TunnelQuotaTimerArgs', 'TunnelQuotaTimer']

@pulumi.input_type
class TunnelQuotaTimerArgs:
    def __init__(__self__, *,
                 nickname: pulumi.Input[builtins.str],
                 quota_timers: Optional[pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a TunnelQuotaTimer resource.
        :param pulumi.Input[builtins.str] nickname: The nickname of the exclusive Resource Group (Tunnel Quota) for the level - 1 data transmission service.
        :param pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]] quota_timers: Time-Sharing configuration
               
               > **NOTE:** -- The same reserved Quota resource group supports up to 48 time intervals. The minimum duration of a time interval is 30 minutes. -- After the current data transmission service is configured for time-sharing, if you need to perform a downgrade operation on the data transmission service (package year and month), please reduce the time-sharing concurrency first. -- The effective time of the time-sharing configuration is 0 to 5 minutes, and the billing will be calculated according to the actual effective time. -- Please make sure to set the time range completely from 00:00 to 24:00
               See `quota_timer` below.
        :param pulumi.Input[builtins.str] time_zone: Time zone, reference: Asia/Shanghai
               In general, the system will automatically generate the time zone according to the region without configuration.
        """
        pulumi.set(__self__, "nickname", nickname)
        if quota_timers is not None:
            pulumi.set(__self__, "quota_timers", quota_timers)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)

    @property
    @pulumi.getter
    def nickname(self) -> pulumi.Input[builtins.str]:
        """
        The nickname of the exclusive Resource Group (Tunnel Quota) for the level - 1 data transmission service.
        """
        return pulumi.get(self, "nickname")

    @nickname.setter
    def nickname(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "nickname", value)

    @property
    @pulumi.getter(name="quotaTimers")
    def quota_timers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]]]:
        """
        Time-Sharing configuration

        > **NOTE:** -- The same reserved Quota resource group supports up to 48 time intervals. The minimum duration of a time interval is 30 minutes. -- After the current data transmission service is configured for time-sharing, if you need to perform a downgrade operation on the data transmission service (package year and month), please reduce the time-sharing concurrency first. -- The effective time of the time-sharing configuration is 0 to 5 minutes, and the billing will be calculated according to the actual effective time. -- Please make sure to set the time range completely from 00:00 to 24:00
        See `quota_timer` below.
        """
        return pulumi.get(self, "quota_timers")

    @quota_timers.setter
    def quota_timers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]]]):
        pulumi.set(self, "quota_timers", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time zone, reference: Asia/Shanghai
        In general, the system will automatically generate the time zone according to the region without configuration.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "time_zone", value)


@pulumi.input_type
class _TunnelQuotaTimerState:
    def __init__(__self__, *,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 quota_timers: Optional[pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TunnelQuotaTimer resources.
        :param pulumi.Input[builtins.str] nickname: The nickname of the exclusive Resource Group (Tunnel Quota) for the level - 1 data transmission service.
        :param pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]] quota_timers: Time-Sharing configuration
               
               > **NOTE:** -- The same reserved Quota resource group supports up to 48 time intervals. The minimum duration of a time interval is 30 minutes. -- After the current data transmission service is configured for time-sharing, if you need to perform a downgrade operation on the data transmission service (package year and month), please reduce the time-sharing concurrency first. -- The effective time of the time-sharing configuration is 0 to 5 minutes, and the billing will be calculated according to the actual effective time. -- Please make sure to set the time range completely from 00:00 to 24:00
               See `quota_timer` below.
        :param pulumi.Input[builtins.str] time_zone: Time zone, reference: Asia/Shanghai
               In general, the system will automatically generate the time zone according to the region without configuration.
        """
        if nickname is not None:
            pulumi.set(__self__, "nickname", nickname)
        if quota_timers is not None:
            pulumi.set(__self__, "quota_timers", quota_timers)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)

    @property
    @pulumi.getter
    def nickname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The nickname of the exclusive Resource Group (Tunnel Quota) for the level - 1 data transmission service.
        """
        return pulumi.get(self, "nickname")

    @nickname.setter
    def nickname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nickname", value)

    @property
    @pulumi.getter(name="quotaTimers")
    def quota_timers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]]]:
        """
        Time-Sharing configuration

        > **NOTE:** -- The same reserved Quota resource group supports up to 48 time intervals. The minimum duration of a time interval is 30 minutes. -- After the current data transmission service is configured for time-sharing, if you need to perform a downgrade operation on the data transmission service (package year and month), please reduce the time-sharing concurrency first. -- The effective time of the time-sharing configuration is 0 to 5 minutes, and the billing will be calculated according to the actual effective time. -- Please make sure to set the time range completely from 00:00 to 24:00
        See `quota_timer` below.
        """
        return pulumi.get(self, "quota_timers")

    @quota_timers.setter
    def quota_timers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TunnelQuotaTimerQuotaTimerArgs']]]]):
        pulumi.set(self, "quota_timers", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Time zone, reference: Asia/Shanghai
        In general, the system will automatically generate the time zone according to the region without configuration.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "time_zone", value)


@pulumi.type_token("alicloud:maxcompute/tunnelQuotaTimer:TunnelQuotaTimer")
class TunnelQuotaTimer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 quota_timers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TunnelQuotaTimerQuotaTimerArgs', 'TunnelQuotaTimerQuotaTimerArgsDict']]]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        Max Compute Tunnel Quota Timer can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/tunnelQuotaTimer:TunnelQuotaTimer example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] nickname: The nickname of the exclusive Resource Group (Tunnel Quota) for the level - 1 data transmission service.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TunnelQuotaTimerQuotaTimerArgs', 'TunnelQuotaTimerQuotaTimerArgsDict']]]] quota_timers: Time-Sharing configuration
               
               > **NOTE:** -- The same reserved Quota resource group supports up to 48 time intervals. The minimum duration of a time interval is 30 minutes. -- After the current data transmission service is configured for time-sharing, if you need to perform a downgrade operation on the data transmission service (package year and month), please reduce the time-sharing concurrency first. -- The effective time of the time-sharing configuration is 0 to 5 minutes, and the billing will be calculated according to the actual effective time. -- Please make sure to set the time range completely from 00:00 to 24:00
               See `quota_timer` below.
        :param pulumi.Input[builtins.str] time_zone: Time zone, reference: Asia/Shanghai
               In general, the system will automatically generate the time zone according to the region without configuration.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TunnelQuotaTimerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Max Compute Tunnel Quota Timer can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:maxcompute/tunnelQuotaTimer:TunnelQuotaTimer example <id>
        ```

        :param str resource_name: The name of the resource.
        :param TunnelQuotaTimerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TunnelQuotaTimerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nickname: Optional[pulumi.Input[builtins.str]] = None,
                 quota_timers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TunnelQuotaTimerQuotaTimerArgs', 'TunnelQuotaTimerQuotaTimerArgsDict']]]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TunnelQuotaTimerArgs.__new__(TunnelQuotaTimerArgs)

            if nickname is None and not opts.urn:
                raise TypeError("Missing required property 'nickname'")
            __props__.__dict__["nickname"] = nickname
            __props__.__dict__["quota_timers"] = quota_timers
            __props__.__dict__["time_zone"] = time_zone
        super(TunnelQuotaTimer, __self__).__init__(
            'alicloud:maxcompute/tunnelQuotaTimer:TunnelQuotaTimer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            nickname: Optional[pulumi.Input[builtins.str]] = None,
            quota_timers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TunnelQuotaTimerQuotaTimerArgs', 'TunnelQuotaTimerQuotaTimerArgsDict']]]]] = None,
            time_zone: Optional[pulumi.Input[builtins.str]] = None) -> 'TunnelQuotaTimer':
        """
        Get an existing TunnelQuotaTimer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] nickname: The nickname of the exclusive Resource Group (Tunnel Quota) for the level - 1 data transmission service.
        :param pulumi.Input[Sequence[pulumi.Input[Union['TunnelQuotaTimerQuotaTimerArgs', 'TunnelQuotaTimerQuotaTimerArgsDict']]]] quota_timers: Time-Sharing configuration
               
               > **NOTE:** -- The same reserved Quota resource group supports up to 48 time intervals. The minimum duration of a time interval is 30 minutes. -- After the current data transmission service is configured for time-sharing, if you need to perform a downgrade operation on the data transmission service (package year and month), please reduce the time-sharing concurrency first. -- The effective time of the time-sharing configuration is 0 to 5 minutes, and the billing will be calculated according to the actual effective time. -- Please make sure to set the time range completely from 00:00 to 24:00
               See `quota_timer` below.
        :param pulumi.Input[builtins.str] time_zone: Time zone, reference: Asia/Shanghai
               In general, the system will automatically generate the time zone according to the region without configuration.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TunnelQuotaTimerState.__new__(_TunnelQuotaTimerState)

        __props__.__dict__["nickname"] = nickname
        __props__.__dict__["quota_timers"] = quota_timers
        __props__.__dict__["time_zone"] = time_zone
        return TunnelQuotaTimer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def nickname(self) -> pulumi.Output[builtins.str]:
        """
        The nickname of the exclusive Resource Group (Tunnel Quota) for the level - 1 data transmission service.
        """
        return pulumi.get(self, "nickname")

    @property
    @pulumi.getter(name="quotaTimers")
    def quota_timers(self) -> pulumi.Output[Optional[Sequence['outputs.TunnelQuotaTimerQuotaTimer']]]:
        """
        Time-Sharing configuration

        > **NOTE:** -- The same reserved Quota resource group supports up to 48 time intervals. The minimum duration of a time interval is 30 minutes. -- After the current data transmission service is configured for time-sharing, if you need to perform a downgrade operation on the data transmission service (package year and month), please reduce the time-sharing concurrency first. -- The effective time of the time-sharing configuration is 0 to 5 minutes, and the billing will be calculated according to the actual effective time. -- Please make sure to set the time range completely from 00:00 to 24:00
        See `quota_timer` below.
        """
        return pulumi.get(self, "quota_timers")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Time zone, reference: Asia/Shanghai
        In general, the system will automatically generate the time zone according to the region without configuration.
        """
        return pulumi.get(self, "time_zone")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HttpRequestHeaderModificationRuleArgs', 'HttpRequestHeaderModificationRule']

@pulumi.input_type
class HttpRequestHeaderModificationRuleArgs:
    def __init__(__self__, *,
                 request_header_modifications: pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]],
                 site_id: pulumi.Input[builtins.int],
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a HttpRequestHeaderModificationRule resource.
        :param pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]] request_header_modifications: The configurations of modifying request headers. You can add, delete, or modify a request header. See `request_header_modification` below.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        pulumi.set(__self__, "request_header_modifications", request_header_modifications)
        pulumi.set(__self__, "site_id", site_id)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="requestHeaderModifications")
    def request_header_modifications(self) -> pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]]:
        """
        The configurations of modifying request headers. You can add, delete, or modify a request header. See `request_header_modification` below.
        """
        return pulumi.get(self, "request_header_modifications")

    @request_header_modifications.setter
    def request_header_modifications(self, value: pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]]):
        pulumi.set(self, "request_header_modifications", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the website configurations.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.input_type
class _HttpRequestHeaderModificationRuleState:
    def __init__(__self__, *,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 request_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering HttpRequestHeaderModificationRule resources.
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]] request_header_modifications: The configurations of modifying request headers. You can add, delete, or modify a request header. See `request_header_modification` below.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if request_header_modifications is not None:
            pulumi.set(__self__, "request_header_modifications", request_header_modifications)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter(name="requestHeaderModifications")
    def request_header_modifications(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]]]:
        """
        The configurations of modifying request headers. You can add, delete, or modify a request header. See `request_header_modification` below.
        """
        return pulumi.get(self, "request_header_modifications")

    @request_header_modifications.setter
    def request_header_modifications(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs']]]]):
        pulumi.set(self, "request_header_modifications", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the website configurations.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)


@pulumi.type_token("alicloud:esa/httpRequestHeaderModificationRule:HttpRequestHeaderModificationRule")
class HttpRequestHeaderModificationRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 request_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs', 'HttpRequestHeaderModificationRuleRequestHeaderModificationArgsDict']]]]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a ESA Http Request Header Modification Rule resource.

        For information about ESA Http Request Header Modification Rule and how to use it, see [What is Http Request Header Modification Rule](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/api-esa-2024-09-10-createhttprequestheadermodificationrule).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        instance = alicloud.esa.RatePlanInstance("instance",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        site = alicloud.esa.Site("site",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=instance.id,
            coverage="overseas",
            access_type="NS")
        default_http_request_header_modification_rule = alicloud.esa.HttpRequestHeaderModificationRule("default",
            rule_name="example_modify",
            request_header_modifications=[{
                "value": "modify1",
                "operation": "modify",
                "name": "example_modify1",
            }],
            site_id=site.id,
            rule_enable="off",
            rule="(http.request.uri eq \\"/content?page=1234\\")",
            site_version=0)
        ```

        ## Import

        ESA Http Request Header Modification Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpRequestHeaderModificationRule:HttpRequestHeaderModificationRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs', 'HttpRequestHeaderModificationRuleRequestHeaderModificationArgsDict']]]] request_header_modifications: The configurations of modifying request headers. You can add, delete, or modify a request header. See `request_header_modification` below.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpRequestHeaderModificationRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Http Request Header Modification Rule resource.

        For information about ESA Http Request Header Modification Rule and how to use it, see [What is Http Request Header Modification Rule](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/api-esa-2024-09-10-createhttprequestheadermodificationrule).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        instance = alicloud.esa.RatePlanInstance("instance",
            type="NS",
            auto_renew=False,
            period=1,
            payment_type="Subscription",
            coverage="overseas",
            auto_pay=True,
            plan_name="high")
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        site = alicloud.esa.Site("site",
            site_name=f"gositecdn-{default['result']}.cn",
            instance_id=instance.id,
            coverage="overseas",
            access_type="NS")
        default_http_request_header_modification_rule = alicloud.esa.HttpRequestHeaderModificationRule("default",
            rule_name="example_modify",
            request_header_modifications=[{
                "value": "modify1",
                "operation": "modify",
                "name": "example_modify1",
            }],
            site_id=site.id,
            rule_enable="off",
            rule="(http.request.uri eq \\"/content?page=1234\\")",
            site_version=0)
        ```

        ## Import

        ESA Http Request Header Modification Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/httpRequestHeaderModificationRule:HttpRequestHeaderModificationRule example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param HttpRequestHeaderModificationRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpRequestHeaderModificationRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 request_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs', 'HttpRequestHeaderModificationRuleRequestHeaderModificationArgsDict']]]]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpRequestHeaderModificationRuleArgs.__new__(HttpRequestHeaderModificationRuleArgs)

            if request_header_modifications is None and not opts.urn:
                raise TypeError("Missing required property 'request_header_modifications'")
            __props__.__dict__["request_header_modifications"] = request_header_modifications
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["config_id"] = None
        super(HttpRequestHeaderModificationRule, __self__).__init__(
            'alicloud:esa/httpRequestHeaderModificationRule:HttpRequestHeaderModificationRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            request_header_modifications: Optional[pulumi.Input[Sequence[pulumi.Input[Union['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs', 'HttpRequestHeaderModificationRuleRequestHeaderModificationArgsDict']]]]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None) -> 'HttpRequestHeaderModificationRule':
        """
        Get an existing HttpRequestHeaderModificationRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] config_id: Config Id
        :param pulumi.Input[Sequence[pulumi.Input[Union['HttpRequestHeaderModificationRuleRequestHeaderModificationArgs', 'HttpRequestHeaderModificationRuleRequestHeaderModificationArgsDict']]]] request_header_modifications: The configurations of modifying request headers. You can add, delete, or modify a request header. See `request_header_modification` below.
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
               - on: open.
               - off: close.
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.int] site_id: The site ID.
        :param pulumi.Input[builtins.int] site_version: The version number of the website configurations.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpRequestHeaderModificationRuleState.__new__(_HttpRequestHeaderModificationRuleState)

        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["request_header_modifications"] = request_header_modifications
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        return HttpRequestHeaderModificationRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        Config Id
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter(name="requestHeaderModifications")
    def request_header_modifications(self) -> pulumi.Output[Sequence['outputs.HttpRequestHeaderModificationRuleRequestHeaderModification']]:
        """
        The configurations of modifying request headers. You can add, delete, or modify a request header. See `request_header_modification` below.
        """
        return pulumi.get(self, "request_header_modifications")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\")
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        - on: open.
        - off: close.
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The version number of the website configurations.
        """
        return pulumi.get(self, "site_version")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCaCertificatesResult',
    'AwaitableGetCaCertificatesResult',
    'get_ca_certificates',
    'get_ca_certificates_output',
]

@pulumi.output_type
class GetCaCertificatesResult:
    """
    A collection of values returned by getCaCertificates.
    """
    def __init__(__self__, certificates=None, id=None, ids=None, name_regex=None, names=None, output_file=None, resource_group_id=None, tags=None):
        if certificates and not isinstance(certificates, list):
            raise TypeError("Expected argument 'certificates' to be a list")
        pulumi.set(__self__, "certificates", certificates)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def certificates(self) -> Sequence['outputs.GetCaCertificatesCertificateResult']:
        """
        A list of SLB ca certificates. Each element contains the following attributes:
        """
        return pulumi.get(self, "certificates")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of SLB ca certificates IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of SLB ca certificates names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[builtins.str]:
        """
        The resource group Id of CA certificate.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        """
        (Available in v1.66.0+) A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetCaCertificatesResult(GetCaCertificatesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCaCertificatesResult(
            certificates=self.certificates,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            tags=self.tags)


def get_ca_certificates(ids: Optional[Sequence[builtins.str]] = None,
                        name_regex: Optional[builtins.str] = None,
                        output_file: Optional[builtins.str] = None,
                        resource_group_id: Optional[builtins.str] = None,
                        tags: Optional[Mapping[str, builtins.str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCaCertificatesResult:
    """
    This data source provides the CA certificate list.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    sample_ds = alicloud.slb.get_ca_certificates()
    pulumi.export("firstSlbCaCertificateId", sample_ds.certificates[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of ca certificates IDs to filter results.
    :param builtins.str name_regex: A regex string to filter results by ca certificate name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The Id of resource group which ca certificates belongs.
    :param Mapping[str, builtins.str] tags: A mapping of tags to assign to the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:slb/getCaCertificates:getCaCertificates', __args__, opts=opts, typ=GetCaCertificatesResult).value

    return AwaitableGetCaCertificatesResult(
        certificates=pulumi.get(__ret__, 'certificates'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_ca_certificates_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               resource_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCaCertificatesResult]:
    """
    This data source provides the CA certificate list.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    sample_ds = alicloud.slb.get_ca_certificates()
    pulumi.export("firstSlbCaCertificateId", sample_ds.certificates[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of ca certificates IDs to filter results.
    :param builtins.str name_regex: A regex string to filter results by ca certificate name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str resource_group_id: The Id of resource group which ca certificates belongs.
    :param Mapping[str, builtins.str] tags: A mapping of tags to assign to the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:slb/getCaCertificates:getCaCertificates', __args__, opts=opts, typ=GetCaCertificatesResult)
    return __ret__.apply(lambda __response__: GetCaCertificatesResult(
        certificates=pulumi.get(__response__, 'certificates'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PageArgs', 'Page']

@pulumi.input_type
class PageArgs:
    def __init__(__self__, *,
                 content_type: pulumi.Input[builtins.str],
                 page_name: pulumi.Input[builtins.str],
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Page resource.
        :param pulumi.Input[builtins.str] content_type: The Content-Type field in the HTTP header.
        :param pulumi.Input[builtins.str] page_name: The name of the custom response page.
        :param pulumi.Input[builtins.str] content: The Base64-encoded content of the error page. The content type is specified by the Content-Type field.
        :param pulumi.Input[builtins.str] description: The description of the custom error page.
        """
        pulumi.set(__self__, "content_type", content_type)
        pulumi.set(__self__, "page_name", page_name)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> pulumi.Input[builtins.str]:
        """
        The Content-Type field in the HTTP header.
        """
        return pulumi.get(self, "content_type")

    @content_type.setter
    def content_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "content_type", value)

    @property
    @pulumi.getter(name="pageName")
    def page_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the custom response page.
        """
        return pulumi.get(self, "page_name")

    @page_name.setter
    def page_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "page_name", value)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Base64-encoded content of the error page. The content type is specified by the Content-Type field.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the custom error page.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _PageState:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 content_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 page_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Page resources.
        :param pulumi.Input[builtins.str] content: The Base64-encoded content of the error page. The content type is specified by the Content-Type field.
        :param pulumi.Input[builtins.str] content_type: The Content-Type field in the HTTP header.
        :param pulumi.Input[builtins.str] description: The description of the custom error page.
        :param pulumi.Input[builtins.str] page_name: The name of the custom response page.
        """
        if content is not None:
            pulumi.set(__self__, "content", content)
        if content_type is not None:
            pulumi.set(__self__, "content_type", content_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if page_name is not None:
            pulumi.set(__self__, "page_name", page_name)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Base64-encoded content of the error page. The content type is specified by the Content-Type field.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Content-Type field in the HTTP header.
        """
        return pulumi.get(self, "content_type")

    @content_type.setter
    def content_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "content_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the custom error page.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="pageName")
    def page_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the custom response page.
        """
        return pulumi.get(self, "page_name")

    @page_name.setter
    def page_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "page_name", value)


@pulumi.type_token("alicloud:esa/page:Page")
class Page(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 content_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 page_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Page resource.

        For information about ESA Page and how to use it, see [What is Page](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/user-guide/customize-page).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.esa.Page("default",
            description="example resource html page",
            content_type="text/html",
            content="PCFET0NUWVBFIGh0bWw+CjxodG1sIGxhbmc9InpoLUNOIj4KICA8aGVhZD4KICAgIDx0aXRsZT40MDMgRm9yYmlkZGVuPC90aXRsZT4KICA8L2hlYWQ+CiAgPGJvZHk+CiAgICA8aDE+NDAzIEZvcmJpZGRlbjwvaDE+CiAgPC9ib2R5Pgo8L2h0bWw+",
            page_name="resource_example_html_page")
        ```

        ## Import

        ESA Page can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/page:Page example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] content: The Base64-encoded content of the error page. The content type is specified by the Content-Type field.
        :param pulumi.Input[builtins.str] content_type: The Content-Type field in the HTTP header.
        :param pulumi.Input[builtins.str] description: The description of the custom error page.
        :param pulumi.Input[builtins.str] page_name: The name of the custom response page.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Page resource.

        For information about ESA Page and how to use it, see [What is Page](https://www.alibabacloud.com/help/en/edge-security-acceleration/esa/user-guide/customize-page).

        > **NOTE:** Available since v1.242.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.esa.Page("default",
            description="example resource html page",
            content_type="text/html",
            content="PCFET0NUWVBFIGh0bWw+CjxodG1sIGxhbmc9InpoLUNOIj4KICA8aGVhZD4KICAgIDx0aXRsZT40MDMgRm9yYmlkZGVuPC90aXRsZT4KICA8L2hlYWQ+CiAgPGJvZHk+CiAgICA8aDE+NDAzIEZvcmJpZGRlbjwvaDE+CiAgPC9ib2R5Pgo8L2h0bWw+",
            page_name="resource_example_html_page")
        ```

        ## Import

        ESA Page can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/page:Page example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[builtins.str]] = None,
                 content_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 page_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PageArgs.__new__(PageArgs)

            __props__.__dict__["content"] = content
            if content_type is None and not opts.urn:
                raise TypeError("Missing required property 'content_type'")
            __props__.__dict__["content_type"] = content_type
            __props__.__dict__["description"] = description
            if page_name is None and not opts.urn:
                raise TypeError("Missing required property 'page_name'")
            __props__.__dict__["page_name"] = page_name
        super(Page, __self__).__init__(
            'alicloud:esa/page:Page',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content: Optional[pulumi.Input[builtins.str]] = None,
            content_type: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            page_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Page':
        """
        Get an existing Page resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] content: The Base64-encoded content of the error page. The content type is specified by the Content-Type field.
        :param pulumi.Input[builtins.str] content_type: The Content-Type field in the HTTP header.
        :param pulumi.Input[builtins.str] description: The description of the custom error page.
        :param pulumi.Input[builtins.str] page_name: The name of the custom response page.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PageState.__new__(_PageState)

        __props__.__dict__["content"] = content
        __props__.__dict__["content_type"] = content_type
        __props__.__dict__["description"] = description
        __props__.__dict__["page_name"] = page_name
        return Page(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Base64-encoded content of the error page. The content type is specified by the Content-Type field.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> pulumi.Output[builtins.str]:
        """
        The Content-Type field in the HTTP header.
        """
        return pulumi.get(self, "content_type")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the custom error page.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="pageName")
    def page_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the custom response page.
        """
        return pulumi.get(self, "page_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSystemSecurityPoliciesResult',
    'AwaitableGetSystemSecurityPoliciesResult',
    'get_system_security_policies',
    'get_system_security_policies_output',
]

@pulumi.output_type
class GetSystemSecurityPoliciesResult:
    """
    A collection of values returned by getSystemSecurityPolicies.
    """
    def __init__(__self__, id=None, ids=None, output_file=None, policies=None, tags=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of System Security Policy IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetSystemSecurityPoliciesPolicyResult']:
        """
        A list of ALB Security Policies. Each element contains the following attributes:
        """
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        return pulumi.get(self, "tags")


class AwaitableGetSystemSecurityPoliciesResult(GetSystemSecurityPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSystemSecurityPoliciesResult(
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            policies=self.policies,
            tags=self.tags)


def get_system_security_policies(ids: Optional[Sequence[builtins.str]] = None,
                                 output_file: Optional[builtins.str] = None,
                                 tags: Optional[Mapping[str, builtins.str]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSystemSecurityPoliciesResult:
    """
    This data source provides the ALB System Security Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.183.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    defaults = alicloud.alb.get_system_security_policies(ids=["tls_cipher_policy_1_0"])
    pulumi.export("albSystemSecurityPolicyId1", defaults.policies[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of System Security Policy IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:alb/getSystemSecurityPolicies:getSystemSecurityPolicies', __args__, opts=opts, typ=GetSystemSecurityPoliciesResult).value

    return AwaitableGetSystemSecurityPoliciesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policies=pulumi.get(__ret__, 'policies'),
        tags=pulumi.get(__ret__, 'tags'))
def get_system_security_policies_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                        output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                        tags: Optional[pulumi.Input[Optional[Mapping[str, builtins.str]]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSystemSecurityPoliciesResult]:
    """
    This data source provides the ALB System Security Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.183.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    defaults = alicloud.alb.get_system_security_policies(ids=["tls_cipher_policy_1_0"])
    pulumi.export("albSystemSecurityPolicyId1", defaults.policies[0].id)
    ```


    :param Sequence[builtins.str] ids: A list of System Security Policy IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:alb/getSystemSecurityPolicies:getSystemSecurityPolicies', __args__, opts=opts, typ=GetSystemSecurityPoliciesResult)
    return __ret__.apply(lambda __response__: GetSystemSecurityPoliciesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        policies=pulumi.get(__response__, 'policies'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAlarmsResult',
    'AwaitableGetAlarmsResult',
    'get_alarms',
    'get_alarms_output',
]

@pulumi.output_type
class GetAlarmsResult:
    """
    A collection of values returned by getAlarms.
    """
    def __init__(__self__, alarms=None, id=None, ids=None, metric_type=None, name_regex=None, names=None, output_file=None, scaling_group_id=None):
        if alarms and not isinstance(alarms, list):
            raise TypeError("Expected argument 'alarms' to be a list")
        pulumi.set(__self__, "alarms", alarms)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if metric_type and not isinstance(metric_type, str):
            raise TypeError("Expected argument 'metric_type' to be a str")
        pulumi.set(__self__, "metric_type", metric_type)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if scaling_group_id and not isinstance(scaling_group_id, str):
            raise TypeError("Expected argument 'scaling_group_id' to be a str")
        pulumi.set(__self__, "scaling_group_id", scaling_group_id)

    @property
    @pulumi.getter
    def alarms(self) -> Sequence['outputs.GetAlarmsAlarmResult']:
        """
        A list of alarms. Each element contains the following attributes:
        """
        return pulumi.get(self, "alarms")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of alarm ids.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="metricType")
    def metric_type(self) -> Optional[builtins.str]:
        """
        The type for the alarm's associated metric.
        """
        return pulumi.get(self, "metric_type")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of alarm names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="scalingGroupId")
    def scaling_group_id(self) -> Optional[builtins.str]:
        """
        The scaling group associated with this alarm.
        """
        return pulumi.get(self, "scaling_group_id")


class AwaitableGetAlarmsResult(GetAlarmsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlarmsResult(
            alarms=self.alarms,
            id=self.id,
            ids=self.ids,
            metric_type=self.metric_type,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            scaling_group_id=self.scaling_group_id)


def get_alarms(ids: Optional[Sequence[builtins.str]] = None,
               metric_type: Optional[builtins.str] = None,
               name_regex: Optional[builtins.str] = None,
               output_file: Optional[builtins.str] = None,
               scaling_group_id: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAlarmsResult:
    """
    This data source provides available alarm resources.

    > **NOTE** Available in 1.72.0+


    :param Sequence[builtins.str] ids: A list of alarm IDs.
    :param builtins.str metric_type: The type for the alarm's associated metric. Supported value: system, custom. "system" means the metric data is collected by Aliyun Cloud Monitor Service(CMS), "custom" means the metric data is upload to CMS by users. Defaults to system.
    :param builtins.str name_regex: A regex string to filter resulting alarms by name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str scaling_group_id: Scaling group id the alarms belong to.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['metricType'] = metric_type
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['scalingGroupId'] = scaling_group_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ess/getAlarms:getAlarms', __args__, opts=opts, typ=GetAlarmsResult).value

    return AwaitableGetAlarmsResult(
        alarms=pulumi.get(__ret__, 'alarms'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        metric_type=pulumi.get(__ret__, 'metric_type'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        scaling_group_id=pulumi.get(__ret__, 'scaling_group_id'))
def get_alarms_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                      metric_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      scaling_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAlarmsResult]:
    """
    This data source provides available alarm resources.

    > **NOTE** Available in 1.72.0+


    :param Sequence[builtins.str] ids: A list of alarm IDs.
    :param builtins.str metric_type: The type for the alarm's associated metric. Supported value: system, custom. "system" means the metric data is collected by Aliyun Cloud Monitor Service(CMS), "custom" means the metric data is upload to CMS by users. Defaults to system.
    :param builtins.str name_regex: A regex string to filter resulting alarms by name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str scaling_group_id: Scaling group id the alarms belong to.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['metricType'] = metric_type
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['scalingGroupId'] = scaling_group_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ess/getAlarms:getAlarms', __args__, opts=opts, typ=GetAlarmsResult)
    return __ret__.apply(lambda __response__: GetAlarmsResult(
        alarms=pulumi.get(__response__, 'alarms'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        metric_type=pulumi.get(__response__, 'metric_type'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        scaling_group_id=pulumi.get(__response__, 'scaling_group_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NetworkOptimizationArgs', 'NetworkOptimization']

@pulumi.input_type
class NetworkOptimizationArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 grpc: Optional[pulumi.Input[builtins.str]] = None,
                 http2_origin: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 smart_routing: Optional[pulumi.Input[builtins.str]] = None,
                 upload_max_filesize: Optional[pulumi.Input[builtins.str]] = None,
                 websocket: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NetworkOptimization resource.
        :param pulumi.Input[builtins.int] site_id: Site ID.
        :param pulumi.Input[builtins.str] grpc: Whether to enable GRPC, default is disabled. Value range:
        :param pulumi.Input[builtins.str] http2_origin: Whether to enable HTTP2 origin, default is disabled. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_version: Site version number.
        :param pulumi.Input[builtins.str] smart_routing: Whether to enable smart routing service, default is disabled. Value range:
        :param pulumi.Input[builtins.str] upload_max_filesize: Maximum upload file size, in MB, value range: 100～500.
        :param pulumi.Input[builtins.str] websocket: Whether to enable Websocket, default is enabled. Value range:
        """
        pulumi.set(__self__, "site_id", site_id)
        if grpc is not None:
            pulumi.set(__self__, "grpc", grpc)
        if http2_origin is not None:
            pulumi.set(__self__, "http2_origin", http2_origin)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if smart_routing is not None:
            pulumi.set(__self__, "smart_routing", smart_routing)
        if upload_max_filesize is not None:
            pulumi.set(__self__, "upload_max_filesize", upload_max_filesize)
        if websocket is not None:
            pulumi.set(__self__, "websocket", websocket)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        Site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter
    def grpc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable GRPC, default is disabled. Value range:
        """
        return pulumi.get(self, "grpc")

    @grpc.setter
    def grpc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "grpc", value)

    @property
    @pulumi.getter(name="http2Origin")
    def http2_origin(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HTTP2 origin, default is disabled. Value range:
        """
        return pulumi.get(self, "http2_origin")

    @http2_origin.setter
    def http2_origin(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http2_origin", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content.
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. Values:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Site version number.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter(name="smartRouting")
    def smart_routing(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable smart routing service, default is disabled. Value range:
        """
        return pulumi.get(self, "smart_routing")

    @smart_routing.setter
    def smart_routing(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "smart_routing", value)

    @property
    @pulumi.getter(name="uploadMaxFilesize")
    def upload_max_filesize(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Maximum upload file size, in MB, value range: 100～500.
        """
        return pulumi.get(self, "upload_max_filesize")

    @upload_max_filesize.setter
    def upload_max_filesize(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "upload_max_filesize", value)

    @property
    @pulumi.getter
    def websocket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable Websocket, default is enabled. Value range:
        """
        return pulumi.get(self, "websocket")

    @websocket.setter
    def websocket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "websocket", value)


@pulumi.input_type
class _NetworkOptimizationState:
    def __init__(__self__, *,
                 config_id: Optional[pulumi.Input[builtins.int]] = None,
                 grpc: Optional[pulumi.Input[builtins.str]] = None,
                 http2_origin: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 smart_routing: Optional[pulumi.Input[builtins.str]] = None,
                 upload_max_filesize: Optional[pulumi.Input[builtins.str]] = None,
                 websocket: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NetworkOptimization resources.
        :param pulumi.Input[builtins.int] config_id: ConfigId of the configuration, which can be obtained by calling the ListNetworkOptimizations.
        :param pulumi.Input[builtins.str] grpc: Whether to enable GRPC, default is disabled. Value range:
        :param pulumi.Input[builtins.str] http2_origin: Whether to enable HTTP2 origin, default is disabled. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_id: Site ID.
        :param pulumi.Input[builtins.int] site_version: Site version number.
        :param pulumi.Input[builtins.str] smart_routing: Whether to enable smart routing service, default is disabled. Value range:
        :param pulumi.Input[builtins.str] upload_max_filesize: Maximum upload file size, in MB, value range: 100～500.
        :param pulumi.Input[builtins.str] websocket: Whether to enable Websocket, default is enabled. Value range:
        """
        if config_id is not None:
            pulumi.set(__self__, "config_id", config_id)
        if grpc is not None:
            pulumi.set(__self__, "grpc", grpc)
        if http2_origin is not None:
            pulumi.set(__self__, "http2_origin", http2_origin)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if smart_routing is not None:
            pulumi.set(__self__, "smart_routing", smart_routing)
        if upload_max_filesize is not None:
            pulumi.set(__self__, "upload_max_filesize", upload_max_filesize)
        if websocket is not None:
            pulumi.set(__self__, "websocket", websocket)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        ConfigId of the configuration, which can be obtained by calling the ListNetworkOptimizations.
        """
        return pulumi.get(self, "config_id")

    @config_id.setter
    def config_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "config_id", value)

    @property
    @pulumi.getter
    def grpc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable GRPC, default is disabled. Value range:
        """
        return pulumi.get(self, "grpc")

    @grpc.setter
    def grpc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "grpc", value)

    @property
    @pulumi.getter(name="http2Origin")
    def http2_origin(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable HTTP2 origin, default is disabled. Value range:
        """
        return pulumi.get(self, "http2_origin")

    @http2_origin.setter
    def http2_origin(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http2_origin", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content.
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. Values:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Site ID.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Site version number.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter(name="smartRouting")
    def smart_routing(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable smart routing service, default is disabled. Value range:
        """
        return pulumi.get(self, "smart_routing")

    @smart_routing.setter
    def smart_routing(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "smart_routing", value)

    @property
    @pulumi.getter(name="uploadMaxFilesize")
    def upload_max_filesize(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Maximum upload file size, in MB, value range: 100～500.
        """
        return pulumi.get(self, "upload_max_filesize")

    @upload_max_filesize.setter
    def upload_max_filesize(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "upload_max_filesize", value)

    @property
    @pulumi.getter
    def websocket(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable Websocket, default is enabled. Value range:
        """
        return pulumi.get(self, "websocket")

    @websocket.setter
    def websocket(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "websocket", value)


@pulumi.type_token("alicloud:esa/networkOptimization:NetworkOptimization")
class NetworkOptimization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 grpc: Optional[pulumi.Input[builtins.str]] = None,
                 http2_origin: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 smart_routing: Optional[pulumi.Input[builtins.str]] = None,
                 upload_max_filesize: Optional[pulumi.Input[builtins.str]] = None,
                 websocket: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Network Optimization resource.

        For information about ESA Network Optimization and how to use it, see [What is Network Optimization](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateNetworkOptimization).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_site = alicloud.esa.Site("default",
            site_name=f"gositecdn-{default_integer['result']}.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_network_optimization = alicloud.esa.NetworkOptimization("default",
            site_version=0,
            site_id=default_site.id,
            rule_enable="on",
            websocket="off",
            rule="(http.host eq \\"tf.example.com\\")",
            grpc="off",
            http2_origin="off",
            smart_routing="off",
            upload_max_filesize="100",
            rule_name="network_optimization")
        ```

        ## Import

        ESA Network Optimization can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/networkOptimization:NetworkOptimization example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] grpc: Whether to enable GRPC, default is disabled. Value range:
        :param pulumi.Input[builtins.str] http2_origin: Whether to enable HTTP2 origin, default is disabled. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_id: Site ID.
        :param pulumi.Input[builtins.int] site_version: Site version number.
        :param pulumi.Input[builtins.str] smart_routing: Whether to enable smart routing service, default is disabled. Value range:
        :param pulumi.Input[builtins.str] upload_max_filesize: Maximum upload file size, in MB, value range: 100～500.
        :param pulumi.Input[builtins.str] websocket: Whether to enable Websocket, default is enabled. Value range:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkOptimizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Network Optimization resource.

        For information about ESA Network Optimization and how to use it, see [What is Network Optimization](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateNetworkOptimization).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_integer = random.index.Integer("default",
            min=10000,
            max=99999)
        default_site = alicloud.esa.Site("default",
            site_name=f"gositecdn-{default_integer['result']}.cn",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_network_optimization = alicloud.esa.NetworkOptimization("default",
            site_version=0,
            site_id=default_site.id,
            rule_enable="on",
            websocket="off",
            rule="(http.host eq \\"tf.example.com\\")",
            grpc="off",
            http2_origin="off",
            smart_routing="off",
            upload_max_filesize="100",
            rule_name="network_optimization")
        ```

        ## Import

        ESA Network Optimization can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/networkOptimization:NetworkOptimization example <site_id>:<config_id>
        ```

        :param str resource_name: The name of the resource.
        :param NetworkOptimizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkOptimizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 grpc: Optional[pulumi.Input[builtins.str]] = None,
                 http2_origin: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 smart_routing: Optional[pulumi.Input[builtins.str]] = None,
                 upload_max_filesize: Optional[pulumi.Input[builtins.str]] = None,
                 websocket: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkOptimizationArgs.__new__(NetworkOptimizationArgs)

            __props__.__dict__["grpc"] = grpc
            __props__.__dict__["http2_origin"] = http2_origin
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["smart_routing"] = smart_routing
            __props__.__dict__["upload_max_filesize"] = upload_max_filesize
            __props__.__dict__["websocket"] = websocket
            __props__.__dict__["config_id"] = None
        super(NetworkOptimization, __self__).__init__(
            'alicloud:esa/networkOptimization:NetworkOptimization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config_id: Optional[pulumi.Input[builtins.int]] = None,
            grpc: Optional[pulumi.Input[builtins.str]] = None,
            http2_origin: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None,
            smart_routing: Optional[pulumi.Input[builtins.str]] = None,
            upload_max_filesize: Optional[pulumi.Input[builtins.str]] = None,
            websocket: Optional[pulumi.Input[builtins.str]] = None) -> 'NetworkOptimization':
        """
        Get an existing NetworkOptimization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] config_id: ConfigId of the configuration, which can be obtained by calling the ListNetworkOptimizations.
        :param pulumi.Input[builtins.str] grpc: Whether to enable GRPC, default is disabled. Value range:
        :param pulumi.Input[builtins.str] http2_origin: Whether to enable HTTP2 origin, default is disabled. Value range:
        :param pulumi.Input[builtins.str] rule: Rule content.
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. Values:
        :param pulumi.Input[builtins.str] rule_name: Rule name.
        :param pulumi.Input[builtins.int] site_id: Site ID.
        :param pulumi.Input[builtins.int] site_version: Site version number.
        :param pulumi.Input[builtins.str] smart_routing: Whether to enable smart routing service, default is disabled. Value range:
        :param pulumi.Input[builtins.str] upload_max_filesize: Maximum upload file size, in MB, value range: 100～500.
        :param pulumi.Input[builtins.str] websocket: Whether to enable Websocket, default is enabled. Value range:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkOptimizationState.__new__(_NetworkOptimizationState)

        __props__.__dict__["config_id"] = config_id
        __props__.__dict__["grpc"] = grpc
        __props__.__dict__["http2_origin"] = http2_origin
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        __props__.__dict__["smart_routing"] = smart_routing
        __props__.__dict__["upload_max_filesize"] = upload_max_filesize
        __props__.__dict__["websocket"] = websocket
        return NetworkOptimization(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configId")
    def config_id(self) -> pulumi.Output[builtins.int]:
        """
        ConfigId of the configuration, which can be obtained by calling the ListNetworkOptimizations.
        """
        return pulumi.get(self, "config_id")

    @property
    @pulumi.getter
    def grpc(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable GRPC, default is disabled. Value range:
        """
        return pulumi.get(self, "grpc")

    @property
    @pulumi.getter(name="http2Origin")
    def http2_origin(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable HTTP2 origin, default is disabled. Value range:
        """
        return pulumi.get(self, "http2_origin")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content.
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. Values:
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        Site ID.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Site version number.
        """
        return pulumi.get(self, "site_version")

    @property
    @pulumi.getter(name="smartRouting")
    def smart_routing(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable smart routing service, default is disabled. Value range:
        """
        return pulumi.get(self, "smart_routing")

    @property
    @pulumi.getter(name="uploadMaxFilesize")
    def upload_max_filesize(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Maximum upload file size, in MB, value range: 100～500.
        """
        return pulumi.get(self, "upload_max_filesize")

    @property
    @pulumi.getter
    def websocket(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Whether to enable Websocket, default is enabled. Value range:
        """
        return pulumi.get(self, "websocket")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SnatEntryArgs', 'SnatEntry']

@pulumi.input_type
class SnatEntryArgs:
    def __init__(__self__, *,
                 cidr_block: pulumi.Input[builtins.str],
                 sag_id: pulumi.Input[builtins.str],
                 snat_ip: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a SnatEntry resource.
        :param pulumi.Input[builtins.str] cidr_block: The destination CIDR block.
        :param pulumi.Input[builtins.str] sag_id: The ID of the SAG instance.
        :param pulumi.Input[builtins.str] snat_ip: The public IP address.
        """
        pulumi.set(__self__, "cidr_block", cidr_block)
        pulumi.set(__self__, "sag_id", sag_id)
        pulumi.set(__self__, "snat_ip", snat_ip)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Input[builtins.str]:
        """
        The destination CIDR block.
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="sagId")
    def sag_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the SAG instance.
        """
        return pulumi.get(self, "sag_id")

    @sag_id.setter
    def sag_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "sag_id", value)

    @property
    @pulumi.getter(name="snatIp")
    def snat_ip(self) -> pulumi.Input[builtins.str]:
        """
        The public IP address.
        """
        return pulumi.get(self, "snat_ip")

    @snat_ip.setter
    def snat_ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "snat_ip", value)


@pulumi.input_type
class _SnatEntryState:
    def __init__(__self__, *,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 sag_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_ip: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering SnatEntry resources.
        :param pulumi.Input[builtins.str] cidr_block: The destination CIDR block.
        :param pulumi.Input[builtins.str] sag_id: The ID of the SAG instance.
        :param pulumi.Input[builtins.str] snat_ip: The public IP address.
        """
        if cidr_block is not None:
            pulumi.set(__self__, "cidr_block", cidr_block)
        if sag_id is not None:
            pulumi.set(__self__, "sag_id", sag_id)
        if snat_ip is not None:
            pulumi.set(__self__, "snat_ip", snat_ip)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The destination CIDR block.
        """
        return pulumi.get(self, "cidr_block")

    @cidr_block.setter
    def cidr_block(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr_block", value)

    @property
    @pulumi.getter(name="sagId")
    def sag_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the SAG instance.
        """
        return pulumi.get(self, "sag_id")

    @sag_id.setter
    def sag_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sag_id", value)

    @property
    @pulumi.getter(name="snatIp")
    def snat_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The public IP address.
        """
        return pulumi.get(self, "snat_ip")

    @snat_ip.setter
    def snat_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "snat_ip", value)


@pulumi.type_token("alicloud:sag/snatEntry:SnatEntry")
class SnatEntry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 sag_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Sag SnatEntry resource. This topic describes how to add a SNAT entry to enable the SNAT function. The SNAT function can hide internal IP addresses and resolve private IP address conflicts. With this function, on-premises sites can access internal IP addresses, but cannot be accessed by internal IP addresses. If you do not add a SNAT entry, on-premises sites can access each other only when all related IP addresses do not conflict.

        For information about Sag SnatEntry and how to use it, see [What is Sag SnatEntry](https://www.alibabacloud.com/help/en/smart-access-gateway/latest/addsnatentry).

        > **NOTE:** Available since v1.61.0.

        > **NOTE:** Only the following regions support. [`cn-shanghai`, `cn-shanghai-finance-1`, `cn-hongkong`, `ap-southeast-1`, `ap-southeast-3`, `ap-southeast-5`, `ap-northeast-1`, `eu-central-1`]

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        sag_id = config.get("sagId")
        if sag_id is None:
            sag_id = "sag-9bifk***"
        default = alicloud.sag.SnatEntry("default",
            sag_id=sag_id,
            cidr_block="192.168.7.0/24",
            snat_ip="192.0.0.2")
        ```

        ## Import

        The Sag SnatEntry can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sag/snatEntry:SnatEntry example sag-abc123456:snat-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr_block: The destination CIDR block.
        :param pulumi.Input[builtins.str] sag_id: The ID of the SAG instance.
        :param pulumi.Input[builtins.str] snat_ip: The public IP address.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SnatEntryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Sag SnatEntry resource. This topic describes how to add a SNAT entry to enable the SNAT function. The SNAT function can hide internal IP addresses and resolve private IP address conflicts. With this function, on-premises sites can access internal IP addresses, but cannot be accessed by internal IP addresses. If you do not add a SNAT entry, on-premises sites can access each other only when all related IP addresses do not conflict.

        For information about Sag SnatEntry and how to use it, see [What is Sag SnatEntry](https://www.alibabacloud.com/help/en/smart-access-gateway/latest/addsnatentry).

        > **NOTE:** Available since v1.61.0.

        > **NOTE:** Only the following regions support. [`cn-shanghai`, `cn-shanghai-finance-1`, `cn-hongkong`, `ap-southeast-1`, `ap-southeast-3`, `ap-southeast-5`, `ap-northeast-1`, `eu-central-1`]

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        sag_id = config.get("sagId")
        if sag_id is None:
            sag_id = "sag-9bifk***"
        default = alicloud.sag.SnatEntry("default",
            sag_id=sag_id,
            cidr_block="192.168.7.0/24",
            snat_ip="192.0.0.2")
        ```

        ## Import

        The Sag SnatEntry can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:sag/snatEntry:SnatEntry example sag-abc123456:snat-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param SnatEntryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SnatEntryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cidr_block: Optional[pulumi.Input[builtins.str]] = None,
                 sag_id: Optional[pulumi.Input[builtins.str]] = None,
                 snat_ip: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SnatEntryArgs.__new__(SnatEntryArgs)

            if cidr_block is None and not opts.urn:
                raise TypeError("Missing required property 'cidr_block'")
            __props__.__dict__["cidr_block"] = cidr_block
            if sag_id is None and not opts.urn:
                raise TypeError("Missing required property 'sag_id'")
            __props__.__dict__["sag_id"] = sag_id
            if snat_ip is None and not opts.urn:
                raise TypeError("Missing required property 'snat_ip'")
            __props__.__dict__["snat_ip"] = snat_ip
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="alicloud:rocketmq/snatEntry:SnatEntry")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(SnatEntry, __self__).__init__(
            'alicloud:sag/snatEntry:SnatEntry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr_block: Optional[pulumi.Input[builtins.str]] = None,
            sag_id: Optional[pulumi.Input[builtins.str]] = None,
            snat_ip: Optional[pulumi.Input[builtins.str]] = None) -> 'SnatEntry':
        """
        Get an existing SnatEntry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr_block: The destination CIDR block.
        :param pulumi.Input[builtins.str] sag_id: The ID of the SAG instance.
        :param pulumi.Input[builtins.str] snat_ip: The public IP address.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SnatEntryState.__new__(_SnatEntryState)

        __props__.__dict__["cidr_block"] = cidr_block
        __props__.__dict__["sag_id"] = sag_id
        __props__.__dict__["snat_ip"] = snat_ip
        return SnatEntry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Output[builtins.str]:
        """
        The destination CIDR block.
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter(name="sagId")
    def sag_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the SAG instance.
        """
        return pulumi.get(self, "sag_id")

    @property
    @pulumi.getter(name="snatIp")
    def snat_ip(self) -> pulumi.Output[builtins.str]:
        """
        The public IP address.
        """
        return pulumi.get(self, "snat_ip")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDesktopsResult',
    'AwaitableGetDesktopsResult',
    'get_desktops',
    'get_desktops_output',
]

@pulumi.output_type
class GetDesktopsResult:
    """
    A collection of values returned by getDesktops.
    """
    def __init__(__self__, desktop_name=None, desktops=None, end_user_ids=None, id=None, ids=None, name_regex=None, names=None, office_site_id=None, output_file=None, policy_group_id=None, status=None):
        if desktop_name and not isinstance(desktop_name, str):
            raise TypeError("Expected argument 'desktop_name' to be a str")
        pulumi.set(__self__, "desktop_name", desktop_name)
        if desktops and not isinstance(desktops, list):
            raise TypeError("Expected argument 'desktops' to be a list")
        pulumi.set(__self__, "desktops", desktops)
        if end_user_ids and not isinstance(end_user_ids, list):
            raise TypeError("Expected argument 'end_user_ids' to be a list")
        pulumi.set(__self__, "end_user_ids", end_user_ids)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if office_site_id and not isinstance(office_site_id, str):
            raise TypeError("Expected argument 'office_site_id' to be a str")
        pulumi.set(__self__, "office_site_id", office_site_id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if policy_group_id and not isinstance(policy_group_id, str):
            raise TypeError("Expected argument 'policy_group_id' to be a str")
        pulumi.set(__self__, "policy_group_id", policy_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="desktopName")
    def desktop_name(self) -> Optional[builtins.str]:
        return pulumi.get(self, "desktop_name")

    @property
    @pulumi.getter
    def desktops(self) -> Sequence['outputs.GetDesktopsDesktopResult']:
        return pulumi.get(self, "desktops")

    @property
    @pulumi.getter(name="endUserIds")
    def end_user_ids(self) -> Optional[Sequence[builtins.str]]:
        return pulumi.get(self, "end_user_ids")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="officeSiteId")
    def office_site_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "office_site_id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="policyGroupId")
    def policy_group_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "policy_group_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        return pulumi.get(self, "status")


class AwaitableGetDesktopsResult(GetDesktopsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDesktopsResult(
            desktop_name=self.desktop_name,
            desktops=self.desktops,
            end_user_ids=self.end_user_ids,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            office_site_id=self.office_site_id,
            output_file=self.output_file,
            policy_group_id=self.policy_group_id,
            status=self.status)


def get_desktops(desktop_name: Optional[builtins.str] = None,
                 end_user_ids: Optional[Sequence[builtins.str]] = None,
                 ids: Optional[Sequence[builtins.str]] = None,
                 name_regex: Optional[builtins.str] = None,
                 office_site_id: Optional[builtins.str] = None,
                 output_file: Optional[builtins.str] = None,
                 policy_group_id: Optional[builtins.str] = None,
                 status: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDesktopsResult:
    """
    This data source provides the Ecd Desktops of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.144.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_simple_office_site = alicloud.eds.SimpleOfficeSite("default",
        cidr_block="172.16.0.0/12",
        desktop_access_type="Internet",
        office_site_name="your_office_site_name")
    default = alicloud.eds.get_bundles(bundle_type="SYSTEM")
    default_ecd_policy_group = alicloud.eds.EcdPolicyGroup("default",
        policy_group_name="your_policy_group_name",
        clipboard="readwrite",
        local_drive="read",
        authorize_access_policy_rules=[{
            "description": "example_value",
            "cidr_ip": "1.2.3.4/24",
        }],
        authorize_security_policy_rules=[{
            "type": "inflow",
            "policy": "accept",
            "description": "example_value",
            "port_range": "80/80",
            "ip_protocol": "TCP",
            "priority": "1",
            "cidr_ip": "0.0.0.0/0",
        }])
    default_user = alicloud.eds.User("default",
        end_user_id="your_end_user_id",
        email="your_email",
        phone="your_phone",
        password="your_password")
    default_desktop = alicloud.eds.Desktop("default",
        office_site_id=default_simple_office_site.id,
        policy_group_id=default_ecd_policy_group.id,
        bundle_id=default.bundles[0].id,
        desktop_name="your_desktop_name",
        end_user_ids=[default_user.id])
    ids = alicloud.eds.get_desktops_output(ids=[default_desktop.id])
    pulumi.export("ecdDesktopId1", ids.desktops[0].id)
    name_regex = default_desktop.desktop_name.apply(lambda desktop_name: alicloud.eds.get_desktops_output(name_regex=desktop_name))
    pulumi.export("ecdDesktopId2", name_regex.desktops[0].id)
    ```


    :param builtins.str desktop_name: The desktop name.
    :param Sequence[builtins.str] ids: A list of Desktop IDs.
    :param builtins.str name_regex: A regex string to filter results by Desktop name.
    :param builtins.str office_site_id: The ID of the Simple Office Site.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str policy_group_id: The policy group id of the Desktop.
    :param builtins.str status: The status of the Desktop. Valid values: `Deleted`, `Expired`, `Pending`, `Running`, `Starting`, `Stopped`, `Stopping`.
    """
    __args__ = dict()
    __args__['desktopName'] = desktop_name
    __args__['endUserIds'] = end_user_ids
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['officeSiteId'] = office_site_id
    __args__['outputFile'] = output_file
    __args__['policyGroupId'] = policy_group_id
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:eds/getDesktops:getDesktops', __args__, opts=opts, typ=GetDesktopsResult).value

    return AwaitableGetDesktopsResult(
        desktop_name=pulumi.get(__ret__, 'desktop_name'),
        desktops=pulumi.get(__ret__, 'desktops'),
        end_user_ids=pulumi.get(__ret__, 'end_user_ids'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        office_site_id=pulumi.get(__ret__, 'office_site_id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        policy_group_id=pulumi.get(__ret__, 'policy_group_id'),
        status=pulumi.get(__ret__, 'status'))
def get_desktops_output(desktop_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        end_user_ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                        ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                        name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        office_site_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        policy_group_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDesktopsResult]:
    """
    This data source provides the Ecd Desktops of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.144.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_simple_office_site = alicloud.eds.SimpleOfficeSite("default",
        cidr_block="172.16.0.0/12",
        desktop_access_type="Internet",
        office_site_name="your_office_site_name")
    default = alicloud.eds.get_bundles(bundle_type="SYSTEM")
    default_ecd_policy_group = alicloud.eds.EcdPolicyGroup("default",
        policy_group_name="your_policy_group_name",
        clipboard="readwrite",
        local_drive="read",
        authorize_access_policy_rules=[{
            "description": "example_value",
            "cidr_ip": "1.2.3.4/24",
        }],
        authorize_security_policy_rules=[{
            "type": "inflow",
            "policy": "accept",
            "description": "example_value",
            "port_range": "80/80",
            "ip_protocol": "TCP",
            "priority": "1",
            "cidr_ip": "0.0.0.0/0",
        }])
    default_user = alicloud.eds.User("default",
        end_user_id="your_end_user_id",
        email="your_email",
        phone="your_phone",
        password="your_password")
    default_desktop = alicloud.eds.Desktop("default",
        office_site_id=default_simple_office_site.id,
        policy_group_id=default_ecd_policy_group.id,
        bundle_id=default.bundles[0].id,
        desktop_name="your_desktop_name",
        end_user_ids=[default_user.id])
    ids = alicloud.eds.get_desktops_output(ids=[default_desktop.id])
    pulumi.export("ecdDesktopId1", ids.desktops[0].id)
    name_regex = default_desktop.desktop_name.apply(lambda desktop_name: alicloud.eds.get_desktops_output(name_regex=desktop_name))
    pulumi.export("ecdDesktopId2", name_regex.desktops[0].id)
    ```


    :param builtins.str desktop_name: The desktop name.
    :param Sequence[builtins.str] ids: A list of Desktop IDs.
    :param builtins.str name_regex: A regex string to filter results by Desktop name.
    :param builtins.str office_site_id: The ID of the Simple Office Site.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str policy_group_id: The policy group id of the Desktop.
    :param builtins.str status: The status of the Desktop. Valid values: `Deleted`, `Expired`, `Pending`, `Running`, `Starting`, `Stopped`, `Stopping`.
    """
    __args__ = dict()
    __args__['desktopName'] = desktop_name
    __args__['endUserIds'] = end_user_ids
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['officeSiteId'] = office_site_id
    __args__['outputFile'] = output_file
    __args__['policyGroupId'] = policy_group_id
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:eds/getDesktops:getDesktops', __args__, opts=opts, typ=GetDesktopsResult)
    return __ret__.apply(lambda __response__: GetDesktopsResult(
        desktop_name=pulumi.get(__response__, 'desktop_name'),
        desktops=pulumi.get(__response__, 'desktops'),
        end_user_ids=pulumi.get(__response__, 'end_user_ids'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        office_site_id=pulumi.get(__response__, 'office_site_id'),
        output_file=pulumi.get(__response__, 'output_file'),
        policy_group_id=pulumi.get(__response__, 'policy_group_id'),
        status=pulumi.get(__response__, 'status')))
